ID {{ formGroup.controls["id"].value }}
Key {{ formGroup.controls["key"].value }} Name Comment Order Status Settings Enabled Light Mode Enabled View Settings

#### Initial Position

Initial Pan X Initial Pan Y Initial Zoom
Initial Dark Mode Position On Zoom

#### Background Colors

Dark Background Light Background

#### Zoom Limits

Minimum Zoom Maximum Zoom
Grid Sizes
Key Min Max X Grid Y Grid Smallest Text Smallest Shape
Feature Toggles Display Group Templates Enabled Edge Templates Enabled Branches Enabled Edit Settings Edit Enabled
Default Layer Default Level Default Color Default Line Style Default Text Style

#### Vertex Settings

Default Vertex Coord Set Default Vertex Group Name

#### Edge Settings

Default Edge Coord Set Default Edge Group Name
Access Control User Groups Allowed User Groups Denied Additional Data Data (JSON)